@@ -182,7 +182,7 @@ class CustomMultiChoiceField(MultipleChoiceField, BaseCustomField):
             self.choices += _split_choices(splitted_string[0])
 
     def clean(self, *args, **kwargs):
-        args = args if isinstance(args[0], list) else ([args[0]],)
+        # args = args if isinstance(args[0], list) else ([args[0]],)
         return super().clean(*args, **kwargs)
 
     def raise_error(self, name, cleaned_data, **kwargs):
